Enumeration

LspCodeActionKind

Declaration

enum Lsp.CodeActionKind

Description

No description available.

Members

LSP_CODE_ACTION_KIND_EMPTY

Empty kind.

  • Value: 0
  • Available since: 3.0
LSP_CODE_ACTION_KIND_QUICK_FIX

Base kind for quickfix actions: ‘quickfix’.

  • Value: 1
  • Available since: 3.0
LSP_CODE_ACTION_KIND_REFACTOR

Base kind for refactoring actions: ‘refactor’.

  • Value: 2
  • Available since: 3.0
LSP_CODE_ACTION_KIND_REFACTOR_EXTRACT

Base kind for refactoring extraction actions: ‘refactor.extract’.

Example extract actions:

  • Extract method - Extract function - Extract variable - Extract interface from class - …
  • Value: 3
  • Available since: 3.0
LSP_CODE_ACTION_KIND_REFACTOR_INLINE

Base kind for refactoring inline actions: ‘refactor.inline’.

Example inline actions:

  • Inline function - Inline variable - Inline constant - …
  • Value: 4
  • Available since: 3.0
LSP_CODE_ACTION_KIND_REFACTOR_REWRITE

Base kind for refactoring rewrite actions: ‘refactor.rewrite’.

Example rewrite actions:

  • Convert JavaScript function to class - Add or remove parameter - Encapsulate field - Make method static - Move method to base class - …
  • Value: 5
  • Available since: 3.0
LSP_CODE_ACTION_KIND_SOURCE

Base kind for source actions: source.

Source code actions apply to the entire file.

  • Value: 6
  • Available since: 3.0
LSP_CODE_ACTION_KIND_SOURCE_ORGANIZE_IMPORTS

Base kind for an organize imports source action: source.organizeImports.

  • Value: 7
  • Available since: 3.0
LSP_CODE_ACTION_KIND_SOURCE_FIX_ALL

Base kind for a ‘fix all’ source action: source.fixAll.

Fix all’ actions automatically fix errors that have a clear fix that do not require user input. They should not suppress errors or perform unsafe fixes such as generating new types or classes.

Since: 3.17.0.

  • Value: 8
  • Available since: 3.0