Enumeration

LspCodeActionTriggerKind

Declaration

enum Lsp.CodeActionTriggerKind

Description

The reason why code actions were requested.

Since: 3.17.0.

Members

LSP_CODE_ACTION_TRIGGER_KIND_UNSET

No trigger or unknown.

  • Value: 0
  • Available since: 3.0
LSP_CODE_ACTION_TRIGGER_KIND_INVOKED

Code actions were explicitly requested by the user or by an extension.

  • Value: 1
  • Available since: 3.0
LSP_CODE_ACTION_TRIGGER_KIND_AUTOMATIC

Code actions were requested automatically.

This typically happens when current selection in a file changes, but can also be triggered when file content changes.

  • Value: 2
  • Available since: 3.0