Enumeration

LspInsertTextFormat

Declaration

enum Lsp.InsertTextFormat

Description

No description available.

Members

LSP_INSERT_TEXT_FORMAT_UNSET

No description available.

  • Value: 0
  • Available since: 3.0
LSP_INSERT_TEXT_FORMAT_PLAINTEXT

The primary text to be inserted is treated as a plain string.

  • Value: 1
  • Available since: 3.0
LSP_INSERT_TEXT_FORMAT_SNIPPET

The primary text to be inserted is treated as a snippet.

A snippet can define tab stops and placeholders with $1, $2 and ${3:foo}. $0 defines the final tab stop, it defaults to the end of the snippet. Placeholders with equal identifiers are linked, that is typing in one will update others too.

  • Value: 2
  • Available since: 3.0