Enumeration

LspTextDocumentSyncKind

Declaration

enum Lsp.TextDocumentSyncKind

Description

Describes how the host (editor) should sync document changes to the language server.

Members

LSP_TEXT_DOCUMENT_SYNC_KIND_NONE

Documents should not be synced at all.

  • Value: 0
  • Available since: 3.0
LSP_TEXT_DOCUMENT_SYNC_KIND_FULL

Documents are synced by always sending the full content of the document.

  • Value: 1
  • Available since: 3.0
LSP_TEXT_DOCUMENT_SYNC_KIND_INCREMENTAL

Documents are synced by sending the full content on open. After that only incremental updates to the document are sent.

  • Value: 2
  • Available since: 3.0