Enumeration

LspTraceValue

Declaration

enum Lsp.TraceValue

Description

A TraceValue represents the level of verbosity with which the server systematically reports its execution trace using $/logTrace notifications. The initial trace value is set by the client at initialization and can be modified later using the $/setTrace notification.

Members

LSP_TRACE_VALUE_OFF

No description available.

  • Value: 0
  • Available since: 3.0
LSP_TRACE_VALUE_MESSAGES

No description available.

  • Value: 1
  • Available since: 3.0
LSP_TRACE_VALUE_VERBOSE

No description available.

  • Value: 2
  • Available since: 3.0