Struct

LspCodeLens

Description

struct LspCodeLens {
  /* No available fields */
}

A code lens represents a command that should be shown along with source text, like the number of references, a way to run tests, etc.

Constructors

lsp_code_lens_new
No description available.

lsp_code_lens_new_from_variant
No description available.

Instance methods

lsp_code_lens_ref
No description available.

lsp_code_lens_unref
No description available.

lsp_code_lens_get_range

Gets the value of range.

lsp_code_lens_set_range

Sets the value of range.

lsp_code_lens_get_command

Gets the value of command.

lsp_code_lens_set_command

Sets the value of command.

lsp_code_lens_get_data

Gets the value of data.

lsp_code_lens_set_data

Sets the value of data.

lsp_code_lens_to_variant
No description available.