Struct

LspDiagnostic

Description

struct LspDiagnostic {
  /* No available fields */
}

Represents a diagnostic, such as a compiler error or warning.

Diagnostic objects are only valid in the scope of a resource.

Constructors

lsp_diagnostic_new
No description available.

lsp_diagnostic_new_from_variant
No description available.

Instance methods

lsp_diagnostic_ref
No description available.

lsp_diagnostic_unref
No description available.

lsp_diagnostic_get_range

Gets the value of range.

lsp_diagnostic_set_range

Sets the value of range.

lsp_diagnostic_get_severity

Gets the value of severity.

lsp_diagnostic_set_severity

Sets the value of severity.

lsp_diagnostic_get_code

Gets the value of code.

lsp_diagnostic_set_code

Sets the value of code.

lsp_diagnostic_get_code_description

Gets the value of code_description.

lsp_diagnostic_set_code_description

Sets the value of code_description.

lsp_diagnostic_get_source

Gets the value of source.

lsp_diagnostic_set_source

Sets the value of source.

lsp_diagnostic_get_message

Gets the value of message.

lsp_diagnostic_set_message

Sets the value of message.

lsp_diagnostic_get_tags

Gets the value of tags.

lsp_diagnostic_set_tags

Sets the value of tags.

lsp_diagnostic_get_related_information

Gets the value of related_information.

lsp_diagnostic_set_related_information

Sets the value of related_information.

lsp_diagnostic_add_related_information

Appends related information to LspDiagnostic:related-information.

lsp_diagnostic_get_data

Gets the value of data.

lsp_diagnostic_set_data

Sets the value of data.

lsp_diagnostic_to_variant
No description available.