Struct

LspDiagnosticRelatedInformation

Description

struct LspDiagnosticRelatedInformation {
  /* No available fields */
}

Represents a related message and source code location for a diagnostic.

This should be used to point to code locations that cause or are related to a diagnostics, e.g when duplicating a symbol in a scope.

Constructors

Instance methods