Struct

LspDocumentHighlight

Description

struct LspDocumentHighlight {
  LspRange _range;
  LspDocumentHighlightKind _kind;
}

A document highlight is a range inside a text document which deserves special attention. Usually a document highlight is visualized by changing the background color of its range.

Structure members
_range: LspRange

The range this highlight applies to.

_kind: LspDocumentHighlightKind

The highlight kind, default is LSP_DOCUMENT_HIGHLIGHT_KIND_TEXT.

Instance methods

lsp_document_highlight_init
No description available.

lsp_document_highlight_init_from_variant
No description available.

lsp_document_highlight_to_variant
No description available.

lsp_document_highlight_get_range

Gets the value of range.

lsp_document_highlight_set_range

Sets the value of range.

lsp_document_highlight_get_kind

Gets the value of kind.

lsp_document_highlight_set_kind

Sets the value of kind.