Struct

LspDocumentSymbolResult

Description

struct LspDocumentSymbolResult {
  /* No available fields */
}

The two result forms supported by textDocument/documentSymbol.

Exactly one member is non-null. Since an empty wire array does not carry enough information to distinguish the alternatives, it is represented as an empty LspDocumentSymbolResult:document-symbols array.

Constructors

Instance methods

lsp_document_symbol_result_ref
No description available.

lsp_document_symbol_result_unref
No description available.

lsp_document_symbol_result_get_document_symbols

Gets the value of document_symbols.

lsp_document_symbol_result_get_symbol_information

Gets the value of symbol_information.

lsp_document_symbol_result_to_variant
No description available.