Struct

LspInlayHint

Description

struct LspInlayHint {
  /* No available fields */
}

An inlay hint is a visual decoration that appears inline with the text, e.g. to show the type of a variable or the name of a parameter.

Since: 3.17.0.

Constructors

lsp_inlay_hint_new
No description available.

lsp_inlay_hint_new_with_label_parts

Creates an inlay hint with structured label parts.

lsp_inlay_hint_new_from_variant
No description available.

Instance methods

lsp_inlay_hint_ref
No description available.

lsp_inlay_hint_unref
No description available.

lsp_inlay_hint_get_position

Gets the value of position.

lsp_inlay_hint_set_position

Sets the value of position.

lsp_inlay_hint_get_label

Gets the value of label.

lsp_inlay_hint_set_label

Sets the value of label.

lsp_inlay_hint_get_label_parts

Gets the value of label_parts.

lsp_inlay_hint_set_label_parts

Sets the value of label_parts.

lsp_inlay_hint_add_label_part

Appends a label part to LspInlayHint:label-parts.

lsp_inlay_hint_get_kind

Gets the value of kind.

lsp_inlay_hint_set_kind

Sets the value of kind.

lsp_inlay_hint_get_text_edits

Gets the value of text_edits.

lsp_inlay_hint_set_text_edits

Sets the value of text_edits.

lsp_inlay_hint_add_text_edit

Appends an edit to LspInlayHint:text-edits.

lsp_inlay_hint_get_tooltip

Gets the value of tooltip.

lsp_inlay_hint_set_tooltip

Sets the value of tooltip.

lsp_inlay_hint_get_padding

Gets the value of padding.

lsp_inlay_hint_set_padding

Sets the value of padding.

lsp_inlay_hint_get_data

Gets the value of data.

lsp_inlay_hint_set_data

Sets the value of data.

lsp_inlay_hint_to_variant
No description available.