Struct

LspMarkupContent

Description

struct LspMarkupContent {
  /* No available fields */
}

A MarkupContent literal represents a string value which content is interpreted based on its kind flag.

Currently the protocol supports plaintext and markdown as markup kinds.

If the kind is markdown then the value can contain fenced code blocks like in GitHub issues.

Here is an example how such a string can be constructed in Vala:

var markdown = new MarkupContent (
 MarkupKind.MARKDOWN,
 "# Header\n" + "Some text\n" + "```vala\n" + "someCode();\n" + "```"
);

Please Note that clients might sanitize the return markdown. A client could decide to remove HTML from the markdown to avoid script execution.

Constructors

lsp_markup_content_new
No description available.

lsp_markup_content_new_from_variant

Deserialize from a GVariant. Accepts either a plain string (treated as plaintext) or a dict with kind and value properties.

Instance methods

lsp_markup_content_ref
No description available.

lsp_markup_content_unref
No description available.

lsp_markup_content_get_kind

Gets the value of kind.

lsp_markup_content_set_kind

Sets the value of kind.

lsp_markup_content_get_value

Gets the value of value.

lsp_markup_content_set_value

Sets the value of value.

lsp_markup_content_to_variant
No description available.