Struct

LspPrepareRenameResult

Description

struct LspPrepareRenameResult {
  LspRange range;
  gboolean has_range;
  gchar* placeholder;
  gboolean default_behavior;
}

The result of checking whether a symbol can be renamed.

When has_range is false, this represents the protocol’s defaultBehavior result. Keeping the range inline avoids allocating it solely to represent the alternative result shape.

Structure members
range: LspRange

No description available.

has_range: gboolean

No description available.

placeholder: gchar*

No description available.

default_behavior: gboolean

No description available.

Instance methods