Struct

LspRange

Description

struct LspRange {
  LspPosition start;
  LspPosition end;
}

A range in a text document expressed as (zero-based) start and end positions.

A range is comparable to a selection in an editor. Therefore the end position is exclusive. If you want to specify a range that contains a line including the line ending character(s) then use an end position denoting the start of the next line.

Structure members
start: LspPosition

The range’s start position.

end: LspPosition

The range’s end position.

Instance methods

lsp_range_init
No description available.

lsp_range_init_from_variant
No description available.

lsp_range_to_variant
No description available.