Struct

LspWorkspaceEditClientCaps

Description

struct LspWorkspaceEditClientCaps {
  LspWorkspaceEditClientFlags _flags;
  LspResourceOperationKind _resource_ops;
  LspFailureHandlingKind _failure_handling;
}

Defines what workspace resource operations the client supports.

This is a value type because all of its capabilities fit in flags and enums. It can therefore be embedded in LspWorkspaceClientCaps without another allocation.

Structure members
_flags: LspWorkspaceEditClientFlags

The client supports versioned document changes in WorkspaceEdits.

_resource_ops: LspResourceOperationKind

The resource operations the client supports. Clients should at least support ‘create’ ( LSP_RESOURCE_OPERATION_KIND_CREATE), ‘rename’ ( LSP_RESOURCE_OPERATION_KIND_RENAME) and ‘delete’ ( LSP_RESOURCE_OPERATION_KIND_DELETE) files and folders.

Since:

3.13.0

See also:

ResourceOperationKind.

_failure_handling: LspFailureHandlingKind

The failure handling strategy of a client if applying the workspace edit fails.

Since:

3.13.0.

Instance methods

lsp_workspace_edit_client_caps_init
No description available.

lsp_workspace_edit_client_caps_to_variant
No description available.

lsp_workspace_edit_client_caps_get_flags

Gets the value of flags.

lsp_workspace_edit_client_caps_set_flags

Sets the value of flags.

lsp_workspace_edit_client_caps_get_resource_ops

Gets the value of resource_ops.

lsp_workspace_edit_client_caps_set_resource_ops

Sets the value of resource_ops.

lsp_workspace_edit_client_caps_get_failure_handling

Gets the value of failure_handling.

lsp_workspace_edit_client_caps_set_failure_handling

Sets the value of failure_handling.