Struct

LspWorkspaceSymbol

Description

struct LspWorkspaceSymbol {
  /* No available fields */
}

A workspace symbol is a symbol that can be returned from the workspace/symbol request. It is similar to LspSymbolInformation but with an extended location that can also be a GUri + LspRange literal.

Since: 3.17.0.

Constructors

lsp_workspace_symbol_new
No description available.

lsp_workspace_symbol_new_from_variant
No description available.

Instance methods

lsp_workspace_symbol_ref
No description available.

lsp_workspace_symbol_unref
No description available.

lsp_workspace_symbol_get_name

Gets the value of name.

lsp_workspace_symbol_set_name

Sets the value of name.

lsp_workspace_symbol_get_kind

Gets the value of kind.

lsp_workspace_symbol_set_kind

Sets the value of kind.

lsp_workspace_symbol_get_tags

Gets the value of tags.

lsp_workspace_symbol_set_tags

Sets the value of tags.

lsp_workspace_symbol_get_container_name

Gets the value of container_name.

lsp_workspace_symbol_set_container_name

Sets the value of container_name.

lsp_workspace_symbol_get_uri

Gets the value of uri.

lsp_workspace_symbol_set_uri

Sets the value of uri.

lsp_workspace_symbol_get_range

Gets the value of range.

lsp_workspace_symbol_set_range

Sets the value of range.

lsp_workspace_symbol_to_variant
No description available.