Enumeration
LspDiagnosticTag
Members
-
LSP_DIAGNOSTIC_TAG_UNSET -
No description available.
- Value:
0 - Available since: 3.0
- Value:
-
LSP_DIAGNOSTIC_TAG_UNNECESSARY -
Unused or unnecessary code.
Clients are allowed to render diagnostics with this tag faded out instead of having an error squiggle.
- Value:
1 - Available since: 3.0
- Value:
-
LSP_DIAGNOSTIC_TAG_DEPRECATED -
Deprecated or obsolete code.
Clients are allowed to render diagnostics with this tag strike through.
- Value:
2 - Available since: 3.0
- Value: