API Version: 3.0
Library Version: 3.0
Generated by gi-docgen 2026.1
struct LspCodeLens { /* No available fields */ }
A code lens represents a command that should be shown along with source text, like the number of references, a way to run tests, etc.
Gets the value of range.
range
Sets the value of range.
Gets the value of command.
command
Sets the value of command.
Gets the value of data.
data
Sets the value of data.
Content