API Version: 3.0
Library Version: 3.0
Generated by gi-docgen 2026.1
struct LspDiagnostic { /* No available fields */ }
Represents a diagnostic, such as a compiler error or warning.
Diagnostic objects are only valid in the scope of a resource.
Gets the value of range.
range
Sets the value of range.
Gets the value of severity.
severity
Sets the value of severity.
Gets the value of code.
code
Sets the value of code.
Gets the value of code_description.
code_description
Sets the value of code_description.
Gets the value of source.
source
Sets the value of source.
Gets the value of message.
message
Sets the value of message.
Gets the value of tags.
tags
Sets the value of tags.
Gets the value of related_information.
related_information
Sets the value of related_information.
Appends related information to LspDiagnostic:related-information.
LspDiagnostic:related-information
Gets the value of data.
data
Sets the value of data.
Content