API Version: 3.0
Library Version: 3.0
Generated by gi-docgen 2026.1
struct LspDiagnosticRelatedInformation { /* No available fields */ }
Represents a related message and source code location for a diagnostic.
This should be used to point to code locations that cause or are related to a diagnostics, e.g when duplicating a symbol in a scope.
Gets the value of location.
location
Sets the value of location.
Gets the value of message.
message
Sets the value of message.
Content