Struct
LspDocumentHighlight
Description
struct LspDocumentHighlight {
LspRange _range;
LspDocumentHighlightKind _kind;
}
A document highlight is a range inside a text document which deserves special attention. Usually a document highlight is visualized by changing the background color of its range.
Structure members
_range:LspRangeThe range this highlight applies to.
_kind:LspDocumentHighlightKindThe highlight kind, default is
LSP_DOCUMENT_HIGHLIGHT_KIND_TEXT.