Struct
LspDocumentSymbolResult
Description
struct LspDocumentSymbolResult {
/* No available fields */
}
The two result forms supported by textDocument/documentSymbol.
Exactly one member is non-null. Since an empty wire array does not carry enough information to distinguish the alternatives, it is represented as an empty LspDocumentSymbolResult:document-symbols array.