API Version: 3.0
Library Version: 3.0
Generated by gi-docgen 2026.1
struct LspInlayHint { /* No available fields */ }
An inlay hint is a visual decoration that appears inline with the text, e.g. to show the type of a variable or the name of a parameter.
Since: 3.17.0.
Creates an inlay hint with structured label parts.
Gets the value of position.
position
Sets the value of position.
Gets the value of label.
label
Sets the value of label.
Gets the value of label_parts.
label_parts
Sets the value of label_parts.
Appends a label part to LspInlayHint:label-parts.
LspInlayHint:label-parts
Gets the value of kind.
kind
Sets the value of kind.
Gets the value of text_edits.
text_edits
Sets the value of text_edits.
Appends an edit to LspInlayHint:text-edits.
LspInlayHint:text-edits
Gets the value of tooltip.
tooltip
Sets the value of tooltip.
Gets the value of padding.
padding
Sets the value of padding.
Gets the value of data.
data
Sets the value of data.
Content