Struct
LspPosition
Description
struct LspPosition {
guint64 line;
guint64 character;
}
Position in a text document expressed as zero-based line and zero-based character offset.
A position is between two characters like an ‘insert’ cursor in a editor. Special values like for example -1 to denote the end of a line are not supported.
Structure members
line:guint64Line position in a document (zero-based).
character:guint64Character offset on a line in a document (zero-based). Assuming that the line is represented as a string, the
charactervalue represents the gap between thecharacterandcharacter + 1.If the character value is greater than the line length it defaults back to the line length.