Struct
LspTextDocumentContentChangeEvent
Description
struct LspTextDocumentContentChangeEvent {
LspRange* _range;
gchar* _text;
}
An event describing a change to a text document. If LspTextDocumentContentChangeEvent:range is omitted the new text is considered to be the full content of the document.
Structure members
_range:LspRangeThe range of the document that changed.
_text:gchar*The new text for the provided range. If
rangeis omitted, this is the new text for the entire document.