Struct
LspWorkspaceEditClientCaps
Description
struct LspWorkspaceEditClientCaps {
LspWorkspaceEditClientFlags _flags;
LspResourceOperationKind _resource_ops;
LspFailureHandlingKind _failure_handling;
}
Defines what workspace resource operations the client supports.
This is a value type because all of its capabilities fit in flags and enums. It can therefore be embedded in LspWorkspaceClientCaps without another allocation.
Structure members
_flags:LspWorkspaceEditClientFlagsThe client supports versioned document changes in WorkspaceEdits.
_resource_ops:LspResourceOperationKindThe resource operations the client supports. Clients should at least support ‘create’ (
LSP_RESOURCE_OPERATION_KIND_CREATE), ‘rename’ (LSP_RESOURCE_OPERATION_KIND_RENAME) and ‘delete’ (LSP_RESOURCE_OPERATION_KIND_DELETE) files and folders.Since:
3.13.0
See also:
_failure_handling:LspFailureHandlingKindThe failure handling strategy of a client if applying the workspace edit fails.
Since:
3.13.0.