Struct
LspWorkspaceSymbol
Description
struct LspWorkspaceSymbol {
/* No available fields */
}
A workspace symbol is a symbol that can be returned from the workspace/symbol request. It is similar to LspSymbolInformation but with an extended location that can also be a GUri + LspRange literal.
Since: 3.17.0.